@@ -139,9 +139,9 @@ class BundleTaskCompleteWaiter(Boto3Waiter):
         self,
         *,
         BundleIds: Sequence[str] = ...,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         DryRun: bool = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.BundleTaskComplete.wait)
@@ -160,7 +160,7 @@ class ConversionTaskCancelledWaiter(Boto3Waiter):
         *,
         ConversionTaskIds: Sequence[str] = ...,
         DryRun: bool = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.ConversionTaskCancelled.wait)
@@ -179,7 +179,7 @@ class ConversionTaskCompletedWaiter(Boto3Waiter):
         *,
         ConversionTaskIds: Sequence[str] = ...,
         DryRun: bool = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.ConversionTaskCompleted.wait)
@@ -198,7 +198,7 @@ class ConversionTaskDeletedWaiter(Boto3Waiter):
         *,
         ConversionTaskIds: Sequence[str] = ...,
         DryRun: bool = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.ConversionTaskDeleted.wait)
@@ -216,9 +216,9 @@ class CustomerGatewayAvailableWaiter(Boto3Waiter):
         self,
         *,
         CustomerGatewayIds: Sequence[str] = ...,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         DryRun: bool = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.CustomerGatewayAvailable.wait)
@@ -236,8 +236,8 @@ class ExportTaskCancelledWaiter(Boto3Waiter):
         self,
         *,
         ExportTaskIds: Sequence[str] = ...,
-        Filters: Sequence["FilterTypeDef"] = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        Filters: Sequence[FilterTypeDef] = ...,
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.ExportTaskCancelled.wait)
@@ -255,8 +255,8 @@ class ExportTaskCompletedWaiter(Boto3Waiter):
         self,
         *,
         ExportTaskIds: Sequence[str] = ...,
-        Filters: Sequence["FilterTypeDef"] = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        Filters: Sequence[FilterTypeDef] = ...,
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.ExportTaskCompleted.wait)
@@ -274,12 +274,12 @@ class ImageAvailableWaiter(Boto3Waiter):
         self,
         *,
         ExecutableUsers: Sequence[str] = ...,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         ImageIds: Sequence[str] = ...,
         Owners: Sequence[str] = ...,
         IncludeDeprecated: bool = ...,
         DryRun: bool = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.ImageAvailable.wait)
@@ -297,12 +297,12 @@ class ImageExistsWaiter(Boto3Waiter):
         self,
         *,
         ExecutableUsers: Sequence[str] = ...,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         ImageIds: Sequence[str] = ...,
         Owners: Sequence[str] = ...,
         IncludeDeprecated: bool = ...,
         DryRun: bool = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.ImageExists.wait)
@@ -319,12 +319,12 @@ class InstanceExistsWaiter(Boto3Waiter):
     def wait(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         InstanceIds: Sequence[str] = ...,
         DryRun: bool = ...,
         MaxResults: int = ...,
         NextToken: str = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.InstanceExists.wait)
@@ -341,12 +341,12 @@ class InstanceRunningWaiter(Boto3Waiter):
     def wait(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         InstanceIds: Sequence[str] = ...,
         DryRun: bool = ...,
         MaxResults: int = ...,
         NextToken: str = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.InstanceRunning.wait)
@@ -363,13 +363,13 @@ class InstanceStatusOkWaiter(Boto3Waiter):
     def wait(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         InstanceIds: Sequence[str] = ...,
         MaxResults: int = ...,
         NextToken: str = ...,
         DryRun: bool = ...,
         IncludeAllInstances: bool = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.InstanceStatusOk.wait)
@@ -386,12 +386,12 @@ class InstanceStoppedWaiter(Boto3Waiter):
     def wait(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         InstanceIds: Sequence[str] = ...,
         DryRun: bool = ...,
         MaxResults: int = ...,
         NextToken: str = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.InstanceStopped.wait)
@@ -408,12 +408,12 @@ class InstanceTerminatedWaiter(Boto3Waiter):
     def wait(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         InstanceIds: Sequence[str] = ...,
         DryRun: bool = ...,
         MaxResults: int = ...,
         NextToken: str = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.InstanceTerminated.wait)
@@ -430,12 +430,12 @@ class InternetGatewayExistsWaiter(Boto3Waiter):
     def wait(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         DryRun: bool = ...,
         InternetGatewayIds: Sequence[str] = ...,
         NextToken: str = ...,
         MaxResults: int = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.InternetGatewayExists.wait)
@@ -452,12 +452,12 @@ class KeyPairExistsWaiter(Boto3Waiter):
     def wait(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         KeyNames: Sequence[str] = ...,
         KeyPairIds: Sequence[str] = ...,
         DryRun: bool = ...,
         IncludePublicKey: bool = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.KeyPairExists.wait)
@@ -475,11 +475,11 @@ class NatGatewayAvailableWaiter(Boto3Waiter):
         self,
         *,
         DryRun: bool = ...,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         MaxResults: int = ...,
         NatGatewayIds: Sequence[str] = ...,
         NextToken: str = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.NatGatewayAvailable.wait)
@@ -497,11 +497,11 @@ class NatGatewayDeletedWaiter(Boto3Waiter):
         self,
         *,
         DryRun: bool = ...,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         MaxResults: int = ...,
         NatGatewayIds: Sequence[str] = ...,
         NextToken: str = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.NatGatewayDeleted.wait)
@@ -518,12 +518,12 @@ class NetworkInterfaceAvailableWaiter(Boto3Waiter):
     def wait(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         DryRun: bool = ...,
         NetworkInterfaceIds: Sequence[str] = ...,
         NextToken: str = ...,
         MaxResults: int = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.NetworkInterfaceAvailable.wait)
@@ -538,7 +538,7 @@ class PasswordDataAvailableWaiter(Boto3Waiter):
     """
 
     def wait(
-        self, *, InstanceId: str, DryRun: bool = ..., WaiterConfig: "WaiterConfigTypeDef" = ...
+        self, *, InstanceId: str, DryRun: bool = ..., WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.PasswordDataAvailable.wait)
@@ -555,13 +555,13 @@ class SecurityGroupExistsWaiter(Boto3Waiter):
     def wait(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         GroupIds: Sequence[str] = ...,
         GroupNames: Sequence[str] = ...,
         DryRun: bool = ...,
         NextToken: str = ...,
         MaxResults: int = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.SecurityGroupExists.wait)
@@ -578,14 +578,14 @@ class SnapshotCompletedWaiter(Boto3Waiter):
     def wait(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         MaxResults: int = ...,
         NextToken: str = ...,
         OwnerIds: Sequence[str] = ...,
         RestorableByUserIds: Sequence[str] = ...,
         SnapshotIds: Sequence[str] = ...,
         DryRun: bool = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.SnapshotCompleted.wait)
@@ -602,12 +602,12 @@ class SpotInstanceRequestFulfilledWaiter(Boto3Waiter):
     def wait(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         DryRun: bool = ...,
         SpotInstanceRequestIds: Sequence[str] = ...,
         NextToken: str = ...,
         MaxResults: int = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.SpotInstanceRequestFulfilled.wait)
@@ -624,12 +624,12 @@ class SubnetAvailableWaiter(Boto3Waiter):
     def wait(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         SubnetIds: Sequence[str] = ...,
         DryRun: bool = ...,
         NextToken: str = ...,
         MaxResults: int = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.SubnetAvailable.wait)
@@ -646,13 +646,13 @@ class SystemStatusOkWaiter(Boto3Waiter):
     def wait(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         InstanceIds: Sequence[str] = ...,
         MaxResults: int = ...,
         NextToken: str = ...,
         DryRun: bool = ...,
         IncludeAllInstances: bool = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.SystemStatusOk.wait)
@@ -669,12 +669,12 @@ class VolumeAvailableWaiter(Boto3Waiter):
     def wait(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         VolumeIds: Sequence[str] = ...,
         DryRun: bool = ...,
         MaxResults: int = ...,
         NextToken: str = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.VolumeAvailable.wait)
@@ -691,12 +691,12 @@ class VolumeDeletedWaiter(Boto3Waiter):
     def wait(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         VolumeIds: Sequence[str] = ...,
         DryRun: bool = ...,
         MaxResults: int = ...,
         NextToken: str = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.VolumeDeleted.wait)
@@ -713,12 +713,12 @@ class VolumeInUseWaiter(Boto3Waiter):
     def wait(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         VolumeIds: Sequence[str] = ...,
         DryRun: bool = ...,
         MaxResults: int = ...,
         NextToken: str = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.VolumeInUse.wait)
@@ -735,12 +735,12 @@ class VpcAvailableWaiter(Boto3Waiter):
     def wait(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         VpcIds: Sequence[str] = ...,
         DryRun: bool = ...,
         NextToken: str = ...,
         MaxResults: int = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.VpcAvailable.wait)
@@ -757,12 +757,12 @@ class VpcExistsWaiter(Boto3Waiter):
     def wait(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         VpcIds: Sequence[str] = ...,
         DryRun: bool = ...,
         NextToken: str = ...,
         MaxResults: int = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.VpcExists.wait)
@@ -779,12 +779,12 @@ class VpcPeeringConnectionDeletedWaiter(Boto3Waiter):
     def wait(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         DryRun: bool = ...,
         VpcPeeringConnectionIds: Sequence[str] = ...,
         NextToken: str = ...,
         MaxResults: int = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.VpcPeeringConnectionDeleted.wait)
@@ -801,12 +801,12 @@ class VpcPeeringConnectionExistsWaiter(Boto3Waiter):
     def wait(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         DryRun: bool = ...,
         VpcPeeringConnectionIds: Sequence[str] = ...,
         NextToken: str = ...,
         MaxResults: int = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.VpcPeeringConnectionExists.wait)
@@ -823,10 +823,10 @@ class VpnConnectionAvailableWaiter(Boto3Waiter):
     def wait(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         VpnConnectionIds: Sequence[str] = ...,
         DryRun: bool = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.VpnConnectionAvailable.wait)
@@ -843,10 +843,10 @@ class VpnConnectionDeletedWaiter(Boto3Waiter):
     def wait(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         VpnConnectionIds: Sequence[str] = ...,
         DryRun: bool = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.VpnConnectionDeleted.wait)
